go/analysis/passes/lostcancel: fix typo

cancelation → cancellation

Change-Id: I40abe4acfc2bf061e20bd9477a520aef6dfe848c
Reviewed-on: https://go-review.googlesource.com/c/tools/+/207845
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
diff --git a/go/analysis/passes/lostcancel/lostcancel.go b/go/analysis/passes/lostcancel/lostcancel.go
index 85e7ba7..de6f840 100644
--- a/go/analysis/passes/lostcancel/lostcancel.go
+++ b/go/analysis/passes/lostcancel/lostcancel.go
@@ -3,7 +3,7 @@
 // license that can be found in the LICENSE file.
 
 // Package lostcancel defines an Analyzer that checks for failure to
 // call a context cancelation function.
 package lostcancel
 
 import (
@@ -20,7 +20,7 @@
 
 const Doc = `check cancel func returned by context.WithCancel is called
 
-The cancelation function returned by context.WithCancel, WithTimeout,
+The cancellation function returned by context.WithCancel, WithTimeout,
 and WithDeadline must be called or the new context will remain live
 until its parent context is cancelled.
 (The background context is never cancelled.)`
@@ -3,7 +3,7 @@
 
 // Package lostcancel defines an Analyzer that checks for failure to
-// call a context cancelation function.
+// call a context cancellation function.
 package lostcancel
 